@@ -33,6 +33,12 @@ extern "C" {
 
 int liqaccel_read(int *ax,int *ay,int *az);
 
+float liqaccel_getangle();	// use most recently read coords to orient self
+int liqaccel_getfat();
+
+#ifdef __cplusplus
+}
+#endif
 
 
 #endif
